==> kubernetes-model-core-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/ListOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ListOptionsBuilder extends ListOptionsFluentImpl<ListOptionsBuilder> implements VisitableBuilder<ListOptions,ListOptionsBuilder> {

    ListOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public ListOptionsBuilder() { 
        this(true);
    }


    public ListOptionsBuilder(Boolean validationEnabled) { 
        this(new ListOptions(), validationEnabled);
    }


    public ListOptionsBuilder(ListOptionsFluent<?> fluent) { 
        this(fluent, true);
    }


    public ListOptionsBuilder(ListOptionsFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ListOptions(), validationEnabled);
    }


    public ListOptionsBuilder(ListOptionsFluent<?> fluent,ListOptions instance) { 
        this(fluent, instance, true);
    }


    public ListOptionsBuilder(ListOptionsFluent<?> fluent,ListOptions instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAllowWatchBookmarks(instance.getAllowWatchBookmarks()); 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withContinue(instance.getContinue()); 
        fluent.withFieldSelector(instance.getFieldSelector()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLabelSelector(instance.getLabelSelector()); 
        fluent.withLimit(instance.getLimit()); 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withTimeoutSeconds(instance.getTimeoutSeconds()); 
        fluent.withWatch(instance.getWatch()); 
        this.validationEnabled = validationEnabled; 
    }


    public ListOptionsBuilder(ListOptions instance) { 
        this(instance,true);
    }


    public ListOptionsBuilder(ListOptions instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAllowWatchBookmarks(instance.getAllowWatchBookmarks()); 
        this.withApiVersion(instance.getApiVersion()); 
        this.withContinue(instance.getContinue()); 
        this.withFieldSelector(instance.getFieldSelector()); 
        this.withKind(instance.getKind()); 
        this.withLabelSelector(instance.getLabelSelector()); 
        this.withLimit(instance.getLimit()); 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
        this.withWatch(instance.getWatch()); 
        this.validationEnabled = validationEnabled; 
    }


    public ListOptions build() {
        ListOptions buildable = new ListOptions(fluent.isAllowWatchBookmarks(),fluent.getApiVersion(),fluent.getContinue(),fluent.getFieldSelector(),fluent.getKind(),fluent.getLabelSelector(),fluent.getLimit(),fluent.getResourceVersion(),fluent.getTimeoutSeconds(),fluent.isWatch());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ListOptionsBuilder that = (ListOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.0.3-sources.jar: io/fabric8/kubernetes/api/model/ListOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ListOptionsBuilder extends ListOptionsFluentImpl<ListOptionsBuilder> implements VisitableBuilder<ListOptions,ListOptionsBuilder> {

    ListOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public ListOptionsBuilder() {
        this(true);
    }

    public ListOptionsBuilder(Boolean validationEnabled) {
        this(new ListOptions(), validationEnabled);
    }

    public ListOptionsBuilder(ListOptionsFluent<?> fluent) {
        this(fluent, true);
    }

    public ListOptionsBuilder(ListOptionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ListOptions(), validationEnabled);
    }

    public ListOptionsBuilder(ListOptionsFluent<?> fluent,ListOptions instance) {
        this(fluent, instance, true);
    }

    public ListOptionsBuilder(ListOptionsFluent<?> fluent,ListOptions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAllowWatchBookmarks(instance.getAllowWatchBookmarks()); 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withContinue(instance.getContinue()); 
        fluent.withFieldSelector(instance.getFieldSelector()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLabelSelector(instance.getLabelSelector()); 
        fluent.withLimit(instance.getLimit()); 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withResourceVersionMatch(instance.getResourceVersionMatch()); 
        fluent.withTimeoutSeconds(instance.getTimeoutSeconds()); 
        fluent.withWatch(instance.getWatch()); 
        this.validationEnabled = validationEnabled; 
    }

    public ListOptionsBuilder(ListOptions instance) {
        this(instance,true);
    }

    public ListOptionsBuilder(ListOptions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAllowWatchBookmarks(instance.getAllowWatchBookmarks()); 
        this.withApiVersion(instance.getApiVersion()); 
        this.withContinue(instance.getContinue()); 
        this.withFieldSelector(instance.getFieldSelector()); 
        this.withKind(instance.getKind()); 
        this.withLabelSelector(instance.getLabelSelector()); 
        this.withLimit(instance.getLimit()); 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withResourceVersionMatch(instance.getResourceVersionMatch()); 
        this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
        this.withWatch(instance.getWatch()); 
        this.validationEnabled = validationEnabled; 
    }

    public ListOptions build() {
        ListOptions buildable = new ListOptions(fluent.isAllowWatchBookmarks(),fluent.getApiVersion(),fluent.getContinue(),fluent.getFieldSelector(),fluent.getKind(),fluent.getLabelSelector(),fluent.getLimit(),fluent.getResourceVersion(),fluent.getResourceVersionMatch(),fluent.getTimeoutSeconds(),fluent.isWatch());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ListOptionsBuilder that = (ListOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
